'use strict';

import React from "react";
import PropTypes from "prop-types";
import {Button} from "react-bootstrap";

import DeleteReportDialog from "./DeleteReportDialog";
import I18nWrapper from "../../i18n/I18nWrapper";
import injectIntl from "../../utils/injectIntl";
import Routes from "../../utils/Routes";
import Utils from "../../utils/Utils";

class ReportRow extends React.Component {
    constructor(props) {
        super(props);
        this.i18n = props.i18n;
        this.state = {
            modalOpen: false
        };
    }

    _onDeleteClick = () => {
        this.setState({modalOpen: true});
    };

    _onCloseModal = () => {
        this.setState({modalOpen: false});
    };

    _onDeleteSubmit = () => {
        this._onCloseModal();
        this.props.actions.deleteReport(this.props.report);
    };

    render() {
        const report = this.props.report;

        return <tr>
            <td className='report-row'><a href={'#' + Routes.reports.path + '/' + report.id}
                                          title={this.i18n('reports.open-tooltip')}
                                          className='breakable'>{report.occurrence.name}</a>
            </td>
            <td className='report-row content-center'>{Utils.formatDate(report.occurrence.startTime)}</td>
            <td className='report-row content-center'>
                {Utils.constantToString(report.occurrence.severity, true)}
            </td>
            <td className='report-row content-center'>
                {Utils.idToName(report.occurrence.type, this.props.types)}
            </td>
            <td className='report-row actions'>
                <Button bsStyle='primary' bsSize='small' title={this.i18n('reports.open-tooltip')}
                        onClick={() => this.props.actions.editReport(report)}>{this.i18n('open')}</Button>
                <Button bsStyle='warning' bsSize='small' title={this.i18n('reports.delete-tooltip')}
                        onClick={this._onDeleteClick}>{this.i18n('delete')}</Button>

                <DeleteReportDialog show={this.state.modalOpen} onClose={this._onCloseModal}
                                    onSubmit={this._onDeleteSubmit}/>
            </td>
        </tr>;
    }
}

ReportRow.propTypes = {
    actions: PropTypes.object.isRequired,
    report: PropTypes.object.isRequired,
    types: PropTypes.array
};

export default injectIntl(I18nWrapper(ReportRow));
