import React from "react";
import PropTypes from "prop-types";
import assign from "object-assign";
import {Button, Form} from "react-bootstrap";
import Typeahead from "react-bootstrap-typeahead";

import I18nWrapper from "../../../i18n/I18nWrapper";
import injectIntl from "../../../utils/injectIntl";
import TypeaheadResultList from "../../typeahead/TypeaheadResultList";
import Utils from "../../../utils/Utils";

class EditedEvent extends React.Component {
    constructor(props) {
        super(props);
        this.i18n = props.i18n;
        this.state = assign({}, props.event);
    }

    _onOptionSelected = (option) => {
        this.setState({type: option.id});
    };

    _onSave = () => {
        this.props.onSave(this.state);
    };

    render() {
        const event = this.state,
            value = Utils.idToName(event.type, this.props.eventTypes),
            typeaheadClasses = {
                input: 'event-type-edit'
            };
        return <tr>
            <td className='vertical-middle'>
                <Form inline>
                    <Typeahead title={this.i18n('occurrence.type')} className='event-type-edit'
                               customClasses={typeaheadClasses}
                               options={this.props.eventTypes} onOptionSelected={this._onOptionSelected} size='small'
                               filterOption='name' value={value} placeholder={this.i18n('eventtype.title')}
                               displayOption='name' formInputOption='id' customListComponent={TypeaheadResultList}/>
                </Form>
            </td>
            <td className='actions'>
                <Button bsStyle='primary' bsSize='small' onClick={this._onSave}
                        disabled={!event.type}>{this.i18n('save')}</Button>
                <Button bsStyle='link' bsSize='small' onClick={this.props.onCancel}>{this.i18n('cancel')}</Button>
            </td>
        </tr>;
    }
}

EditedEvent.propTypes = {
    event: PropTypes.object.isRequired,
    eventTypes: PropTypes.array,
    onSave: PropTypes.func.isRequired,
    onCancel: PropTypes.func.isRequired
};

export default injectIntl(I18nWrapper(EditedEvent));
