package cz.cvut.kbss.reporting.persistence.dao;

import cz.cvut.kbss.reporting.environment.Generator;
import cz.cvut.kbss.reporting.model.OccurrenceReport;
import cz.cvut.kbss.reporting.model.Person;
import cz.cvut.kbss.reporting.persistence.BaseDaoTestRunner;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.IntStream;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

public class OccurrenceReportDaoTest extends BaseDaoTestRunner {

    @Autowired
    private OccurrenceReportDao dao;

    @Autowired
    private PersonDao personDao;

    private Person author;

    @Before
    public void setUp() {
        this.author = Generator.generatePerson();
        personDao.persist(author);
    }

    @Test
    public void findAllReturnsReportsOrderedByOccurrenceStartDescending() {
        final List<OccurrenceReport> reports = generateReports();
        reports.forEach(r -> {
            r.setAuthor(author);
            r.setCreated(LocalDateTime.now());
        });
        Collections.shuffle(reports);
        dao.persist(reports);

        final List<OccurrenceReport> result = dao.findAll();
        assertEquals(reports.size(), result.size());
        OccurrenceReport previous = result.get(0);
        for (int i = 1; i < result.size(); i++) {
            final OccurrenceReport current = result.get(i);
            assertTrue(current.getOccurrence().getStartTime().isBefore(previous.getOccurrence().getStartTime()));
            previous = current;
        }
    }

    private List<OccurrenceReport> generateReports() {
        return IntStream.range(0, Generator.randomInt(5, 10)).mapToObj(i -> Generator.generateReport()).collect(
                Collectors.toList());
    }
}