package cz.cvut.kbss.reporting.service.repository;

import cz.cvut.kbss.reporting.environment.Environment;
import cz.cvut.kbss.reporting.environment.Generator;
import cz.cvut.kbss.reporting.model.OccurrenceReport;
import cz.cvut.kbss.reporting.model.Person;
import cz.cvut.kbss.reporting.service.BaseServiceTestRunner;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

public class OccurrenceReportServiceTest extends BaseServiceTestRunner {

    @Autowired
    private OccurrenceReportService reportService;

    private Person author;

    @Before
    public void setUp() {
        this.author = Generator.generatePerson();
        persistPerson(author);
        Environment.setCurrentUser(author);
    }

    @Test
    public void persistSetsAuthorToCurrentlyLoggedInUserAndCreatedToCurrentTime() {
        final OccurrenceReport report = Generator.generateReport();
        reportService.persist(report);

        final OccurrenceReport result = reportService.find(report.getId());
        assertNotNull(result);
        assertEquals(author, result.getAuthor());
        assertNotNull(result.getCreated());
    }

    @Test
    public void updateSetsLastEditorToCurrentlyLoggedInUserAndLastModifiedToCurrentTime() {
        final OccurrenceReport report = Generator.generateReport();
        reportService.persist(report);
        report.setNarrative("Updated narrative.");
        reportService.update(report);

        final OccurrenceReport result = reportService.find(report.getId());
        assertEquals(author, result.getLastEditor());
        assertNotNull(result.getLastModified());
        assertEquals(report.getNarrative(), result.getNarrative());
    }
}